pub fn usage_matching_edges(
python: &dyn PythonUsageSource,
importer: &ProjectFile,
seeds: &BTreeSet<(ProjectFile, String)>,
) -> Vec<ImportEdge>Expand description
The import edges in importer that bind one of the seeds.
pub fn usage_matching_edges(
python: &dyn PythonUsageSource,
importer: &ProjectFile,
seeds: &BTreeSet<(ProjectFile, String)>,
) -> Vec<ImportEdge>The import edges in importer that bind one of the seeds.