pub fn annotation_class_qualifier_site<'tree>(
graph: &PythonGraphSource<'_>,
python: &dyn PythonUsageSource,
file: &ProjectFile,
source: &str,
node: Node<'tree>,
target: &CodeUnit,
) -> Option<Node<'tree>>Expand description
Return the exact qualifier token when a class target owns part of a structured annotation attribute chain.