Module syntax

Module syntax 

Structs

PythonOverloadDecoratorBindings

Functions

decorator_callee
Return a decorator’s callable expression, peeling an optional invocation.
expression_name_node
Return the name-bearing node of a Python expression using tree-sitter fields.
python_deferred_annotation_identifier_ranges
Parse one exactly mapped deferred annotation and return its identifier ranges.
python_node_is_in_annotation
Whether node is contained by a parser field that Python evaluates as an annotation rather than as an ordinary expression.